# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable

import httpx

from ..types import chat_generate_response_params, chat_generate_response_for_user_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.chat_generate_response_response import ChatGenerateResponseResponse
from ..types.chat_generate_response_for_user_response import ChatGenerateResponseForUserResponse

__all__ = ["ChatResource", "AsyncChatResource"]


class ChatResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ChatResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#accessing-raw-response-data-eg-headers
        """
        return ChatResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ChatResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#with_streaming_response
        """
        return ChatResourceWithStreamingResponse(self)

    def generate_response(
        self,
        *,
        api_key: str,
        language: str | NotGiven = NOT_GIVEN,
        messages: Iterable[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ChatGenerateResponseResponse:
        """
        Generate emotionally intelligent chatbot response based on user input

        Args:
          language: language parameter, defaults to en

          messages: history of messages between user with the role 'user' and chatbot with the role
              'assistant'

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/chat",
            body=maybe_transform(
                {
                    "language": language,
                    "messages": messages,
                },
                chat_generate_response_params.ChatGenerateResponseParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"api_key": api_key}, chat_generate_response_params.ChatGenerateResponseParams),
            ),
            cast_to=ChatGenerateResponseResponse,
        )

    def generate_response_for_user(
        self,
        user_id: str,
        *,
        api_key: str,
        language: str | NotGiven = NOT_GIVEN,
        messages: Iterable[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ChatGenerateResponseForUserResponse:
        """
        Generate emotionally intelligent chatbot response based on user input

        Args:
          language: language parameter, defaults to en

          messages: history of messages between user with the role 'user' and chatbot with the role
              'assistant'

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return self._post(
            f"/chat/{user_id}",
            body=maybe_transform(
                {
                    "language": language,
                    "messages": messages,
                },
                chat_generate_response_for_user_params.ChatGenerateResponseForUserParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"api_key": api_key}, chat_generate_response_for_user_params.ChatGenerateResponseForUserParams
                ),
            ),
            cast_to=ChatGenerateResponseForUserResponse,
        )


class AsyncChatResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncChatResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncChatResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncChatResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#with_streaming_response
        """
        return AsyncChatResourceWithStreamingResponse(self)

    async def generate_response(
        self,
        *,
        api_key: str,
        language: str | NotGiven = NOT_GIVEN,
        messages: Iterable[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ChatGenerateResponseResponse:
        """
        Generate emotionally intelligent chatbot response based on user input

        Args:
          language: language parameter, defaults to en

          messages: history of messages between user with the role 'user' and chatbot with the role
              'assistant'

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/chat",
            body=await async_maybe_transform(
                {
                    "language": language,
                    "messages": messages,
                },
                chat_generate_response_params.ChatGenerateResponseParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"api_key": api_key}, chat_generate_response_params.ChatGenerateResponseParams
                ),
            ),
            cast_to=ChatGenerateResponseResponse,
        )

    async def generate_response_for_user(
        self,
        user_id: str,
        *,
        api_key: str,
        language: str | NotGiven = NOT_GIVEN,
        messages: Iterable[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ChatGenerateResponseForUserResponse:
        """
        Generate emotionally intelligent chatbot response based on user input

        Args:
          language: language parameter, defaults to en

          messages: history of messages between user with the role 'user' and chatbot with the role
              'assistant'

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return await self._post(
            f"/chat/{user_id}",
            body=await async_maybe_transform(
                {
                    "language": language,
                    "messages": messages,
                },
                chat_generate_response_for_user_params.ChatGenerateResponseForUserParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"api_key": api_key}, chat_generate_response_for_user_params.ChatGenerateResponseForUserParams
                ),
            ),
            cast_to=ChatGenerateResponseForUserResponse,
        )


class ChatResourceWithRawResponse:
    def __init__(self, chat: ChatResource) -> None:
        self._chat = chat

        self.generate_response = to_raw_response_wrapper(
            chat.generate_response,
        )
        self.generate_response_for_user = to_raw_response_wrapper(
            chat.generate_response_for_user,
        )


class AsyncChatResourceWithRawResponse:
    def __init__(self, chat: AsyncChatResource) -> None:
        self._chat = chat

        self.generate_response = async_to_raw_response_wrapper(
            chat.generate_response,
        )
        self.generate_response_for_user = async_to_raw_response_wrapper(
            chat.generate_response_for_user,
        )


class ChatResourceWithStreamingResponse:
    def __init__(self, chat: ChatResource) -> None:
        self._chat = chat

        self.generate_response = to_streamed_response_wrapper(
            chat.generate_response,
        )
        self.generate_response_for_user = to_streamed_response_wrapper(
            chat.generate_response_for_user,
        )


class AsyncChatResourceWithStreamingResponse:
    def __init__(self, chat: AsyncChatResource) -> None:
        self._chat = chat

        self.generate_response = async_to_streamed_response_wrapper(
            chat.generate_response,
        )
        self.generate_response_for_user = async_to_streamed_response_wrapper(
            chat.generate_response_for_user,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import create_user_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.create_user_create_response import CreateUserCreateResponse

__all__ = ["CreateUserResource", "AsyncCreateUserResource"]


class CreateUserResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CreateUserResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#accessing-raw-response-data-eg-headers
        """
        return CreateUserResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CreateUserResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#with_streaming_response
        """
        return CreateUserResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        api_key: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CreateUserCreateResponse:
        """
        Create a new user

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/create-user",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"api_key": api_key}, create_user_create_params.CreateUserCreateParams),
            ),
            cast_to=CreateUserCreateResponse,
        )


class AsyncCreateUserResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCreateUserResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncCreateUserResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCreateUserResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#with_streaming_response
        """
        return AsyncCreateUserResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        api_key: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CreateUserCreateResponse:
        """
        Create a new user

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/create-user",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"api_key": api_key}, create_user_create_params.CreateUserCreateParams
                ),
            ),
            cast_to=CreateUserCreateResponse,
        )


class CreateUserResourceWithRawResponse:
    def __init__(self, create_user: CreateUserResource) -> None:
        self._create_user = create_user

        self.create = to_raw_response_wrapper(
            create_user.create,
        )


class AsyncCreateUserResourceWithRawResponse:
    def __init__(self, create_user: AsyncCreateUserResource) -> None:
        self._create_user = create_user

        self.create = async_to_raw_response_wrapper(
            create_user.create,
        )


class CreateUserResourceWithStreamingResponse:
    def __init__(self, create_user: CreateUserResource) -> None:
        self._create_user = create_user

        self.create = to_streamed_response_wrapper(
            create_user.create,
        )


class AsyncCreateUserResourceWithStreamingResponse:
    def __init__(self, create_user: AsyncCreateUserResource) -> None:
        self._create_user = create_user

        self.create = async_to_streamed_response_wrapper(
            create_user.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "GetUserChatRetrieveResponse",
    "User",
    "UserChatCall",
    "UserChatCallResult",
    "UserChatCallResultEmotions",
    "UserChatCallResultMotives",
    "UserChatCallResultPreferences",
]


class UserChatCallResultEmotions(BaseModel):
    approach: Optional[float] = None
    """Approach in percent between 0 and 100."""

    avoidance: Optional[float] = None
    """Avoidance in percent between 0 and 100."""


class UserChatCallResultMotives(BaseModel):
    achievement: Optional[float] = None
    """Achievement motive in percent between 0 and 100."""

    contact: Optional[float] = None
    """Contact motive in percent between 0 and 100."""

    power: Optional[float] = None
    """Power motive in percent between 0 and 100."""


class UserChatCallResultPreferences(BaseModel):
    analytical: Optional[float] = None
    """Analytical Orientation in percent between 0 and 100."""

    detail: Optional[float] = None
    """Orientation towards Details in percent between 0 and 100."""

    external: Optional[float] = None
    """External Orientation in percent between 0 and 100."""

    goal: Optional[float] = None
    """Goal-Orientation in percent between 0 and 100."""

    holistic: Optional[float] = None
    """Holistic Orientation in percent between 0 and 100."""

    internal: Optional[float] = None
    """Internal Orientation in percent between 0 and 100."""

    path: Optional[float] = None
    """Path-Orientation in percent between 0 and 100."""

    realization: Optional[float] = None
    """Orientation towards Realization in percent between 0 and 100."""


class UserChatCallResult(BaseModel):
    emotions: Optional[UserChatCallResultEmotions] = None

    motives: Optional[UserChatCallResultMotives] = None

    preferences: Optional[UserChatCallResultPreferences] = None


class UserChatCall(BaseModel):
    messages: Optional[List[object]] = None
    """
    history of messages between user with the role 'user' and chatbot with the role
    'assistant'
    """

    result: Optional[UserChatCallResult] = None


class User(BaseModel):
    chat_calls: Optional[List[UserChatCall]] = FieldInfo(alias="chatCalls", default=None)

    created_at: Optional[str] = FieldInfo(alias="createdAt", default=None)
    """Date of creation"""

    updated_at: Optional[str] = FieldInfo(alias="updatedAt", default=None)
    """Date of last update"""

    user_id: Optional[str] = FieldInfo(alias="userId", default=None)
    """User id"""


class GetUserChatRetrieveResponse(BaseModel):
    user: Optional[User] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import summarize_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.summarize_create_response import SummarizeCreateResponse

__all__ = ["SummarizeResource", "AsyncSummarizeResource"]


class SummarizeResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SummarizeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#accessing-raw-response-data-eg-headers
        """
        return SummarizeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SummarizeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#with_streaming_response
        """
        return SummarizeResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        api_key: str,
        language: str | NotGiven = NOT_GIVEN,
        text: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SummarizeCreateResponse:
        """
        Generate millionways emotionally-intelligent AI summary based on Text Input.

        Args:
          language: language parameter, defaults to en

          text: text input to be classified

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/summarize",
            body=maybe_transform(
                {
                    "language": language,
                    "text": text,
                },
                summarize_create_params.SummarizeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"api_key": api_key}, summarize_create_params.SummarizeCreateParams),
            ),
            cast_to=SummarizeCreateResponse,
        )


class AsyncSummarizeResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSummarizeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncSummarizeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSummarizeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#with_streaming_response
        """
        return AsyncSummarizeResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        api_key: str,
        language: str | NotGiven = NOT_GIVEN,
        text: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SummarizeCreateResponse:
        """
        Generate millionways emotionally-intelligent AI summary based on Text Input.

        Args:
          language: language parameter, defaults to en

          text: text input to be classified

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/summarize",
            body=await async_maybe_transform(
                {
                    "language": language,
                    "text": text,
                },
                summarize_create_params.SummarizeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"api_key": api_key}, summarize_create_params.SummarizeCreateParams),
            ),
            cast_to=SummarizeCreateResponse,
        )


class SummarizeResourceWithRawResponse:
    def __init__(self, summarize: SummarizeResource) -> None:
        self._summarize = summarize

        self.create = to_raw_response_wrapper(
            summarize.create,
        )


class AsyncSummarizeResourceWithRawResponse:
    def __init__(self, summarize: AsyncSummarizeResource) -> None:
        self._summarize = summarize

        self.create = async_to_raw_response_wrapper(
            summarize.create,
        )


class SummarizeResourceWithStreamingResponse:
    def __init__(self, summarize: SummarizeResource) -> None:
        self._summarize = summarize

        self.create = to_streamed_response_wrapper(
            summarize.create,
        )


class AsyncSummarizeResourceWithStreamingResponse:
    def __init__(self, summarize: AsyncSummarizeResource) -> None:
        self._summarize = summarize

        self.create = async_to_streamed_response_wrapper(
            summarize.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .get_user_list_params import GetUserListParams as GetUserListParams
from .get_user_list_response import GetUserListResponse as GetUserListResponse
from .summarize_create_params import SummarizeCreateParams as SummarizeCreateParams
from .get_call_retrieve_params import GetCallRetrieveParams as GetCallRetrieveParams
from .get_user_retrieve_params import GetUserRetrieveParams as GetUserRetrieveParams
from .create_user_create_params import CreateUserCreateParams as CreateUserCreateParams
from .summarize_create_response import SummarizeCreateResponse as SummarizeCreateResponse
from .analyze_team_create_params import AnalyzeTeamCreateParams as AnalyzeTeamCreateParams
from .get_call_retrieve_response import GetCallRetrieveResponse as GetCallRetrieveResponse
from .get_user_retrieve_response import GetUserRetrieveResponse as GetUserRetrieveResponse
from .chat_result_generate_params import ChatResultGenerateParams as ChatResultGenerateParams
from .create_user_create_response import CreateUserCreateResponse as CreateUserCreateResponse
from .analyze_team_create_response import AnalyzeTeamCreateResponse as AnalyzeTeamCreateResponse
from .chat_generate_response_params import ChatGenerateResponseParams as ChatGenerateResponseParams
from .chat_result_generate_response import ChatResultGenerateResponse as ChatResultGenerateResponse
from .get_user_chat_retrieve_params import GetUserChatRetrieveParams as GetUserChatRetrieveParams
from .categorize_audio_create_params import CategorizeAudioCreateParams as CategorizeAudioCreateParams
from .categorize_text_classify_params import CategorizeTextClassifyParams as CategorizeTextClassifyParams
from .chat_generate_response_response import ChatGenerateResponseResponse as ChatGenerateResponseResponse
from .get_user_chat_retrieve_response import GetUserChatRetrieveResponse as GetUserChatRetrieveResponse
from .categorize_audio_create_response import CategorizeAudioCreateResponse as CategorizeAudioCreateResponse
from .categorize_text_classify_response import CategorizeTextClassifyResponse as CategorizeTextClassifyResponse
from .get_user_analysis_retrieve_params import GetUserAnalysisRetrieveParams as GetUserAnalysisRetrieveParams
from .get_user_analysis_retrieve_response import GetUserAnalysisRetrieveResponse as GetUserAnalysisRetrieveResponse
from .chat_stream_generate_response_params import ChatStreamGenerateResponseParams as ChatStreamGenerateResponseParams
from .chat_generate_response_for_user_params import (
    ChatGenerateResponseForUserParams as ChatGenerateResponseForUserParams,
)
from .chat_stream_generate_response_response import (
    ChatStreamGenerateResponseResponse as ChatStreamGenerateResponseResponse,
)
from .categorize_audio_create_for_user_params import (
    CategorizeAudioCreateForUserParams as CategorizeAudioCreateForUserParams,
)
from .categorize_text_classify_by_user_params import (
    CategorizeTextClassifyByUserParams as CategorizeTextClassifyByUserParams,
)
from .chat_generate_response_for_user_response import (
    ChatGenerateResponseForUserResponse as ChatGenerateResponseForUserResponse,
)
from .sales_assistant_generate_insights_params import (
    SalesAssistantGenerateInsightsParams as SalesAssistantGenerateInsightsParams,
)
from .categorize_audio_create_for_user_response import (
    CategorizeAudioCreateForUserResponse as CategorizeAudioCreateForUserResponse,
)
from .categorize_text_classify_by_user_response import (
    CategorizeTextClassifyByUserResponse as CategorizeTextClassifyByUserResponse,
)
from .sales_assistant_generate_insights_response import (
    SalesAssistantGenerateInsightsResponse as SalesAssistantGenerateInsightsResponse,
)
from .mental_health_chatbot_generate_response_params import (
    MentalHealthChatbotGenerateResponseParams as MentalHealthChatbotGenerateResponseParams,
)
from .mental_health_chatbot_generate_response_response import (
    MentalHealthChatbotGenerateResponseResponse as MentalHealthChatbotGenerateResponseResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Mapping, cast

import httpx

from ..types import categorize_audio_create_params, categorize_audio_create_for_user_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven, FileTypes
from .._utils import extract_files, maybe_transform, deepcopy_minimal, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.categorize_audio_create_response import CategorizeAudioCreateResponse
from ..types.categorize_audio_create_for_user_response import CategorizeAudioCreateForUserResponse

__all__ = ["CategorizeAudioResource", "AsyncCategorizeAudioResource"]


class CategorizeAudioResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CategorizeAudioResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#accessing-raw-response-data-eg-headers
        """
        return CategorizeAudioResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CategorizeAudioResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#with_streaming_response
        """
        return CategorizeAudioResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        api_key: str,
        file: FileTypes | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CategorizeAudioCreateResponse:
        """
        Generate millionways emotionally-smart AI Classification based on Audio Input

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        body = deepcopy_minimal({"file": file})
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._post(
            "/categorize-audio",
            body=maybe_transform(body, categorize_audio_create_params.CategorizeAudioCreateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"api_key": api_key}, categorize_audio_create_params.CategorizeAudioCreateParams),
            ),
            cast_to=CategorizeAudioCreateResponse,
        )

    def create_for_user(
        self,
        user_id: str,
        *,
        api_key: str,
        file: FileTypes | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CategorizeAudioCreateForUserResponse:
        """
        Generate millionways emotionally-smart AI Classification based on Audio Input

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        body = deepcopy_minimal({"file": file})
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._post(
            f"/categorize-audio/{user_id}",
            body=maybe_transform(body, categorize_audio_create_for_user_params.CategorizeAudioCreateForUserParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"api_key": api_key}, categorize_audio_create_for_user_params.CategorizeAudioCreateForUserParams
                ),
            ),
            cast_to=CategorizeAudioCreateForUserResponse,
        )


class AsyncCategorizeAudioResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCategorizeAudioResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncCategorizeAudioResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCategorizeAudioResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#with_streaming_response
        """
        return AsyncCategorizeAudioResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        api_key: str,
        file: FileTypes | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CategorizeAudioCreateResponse:
        """
        Generate millionways emotionally-smart AI Classification based on Audio Input

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        body = deepcopy_minimal({"file": file})
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return await self._post(
            "/categorize-audio",
            body=await async_maybe_transform(body, categorize_audio_create_params.CategorizeAudioCreateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"api_key": api_key}, categorize_audio_create_params.CategorizeAudioCreateParams
                ),
            ),
            cast_to=CategorizeAudioCreateResponse,
        )

    async def create_for_user(
        self,
        user_id: str,
        *,
        api_key: str,
        file: FileTypes | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CategorizeAudioCreateForUserResponse:
        """
        Generate millionways emotionally-smart AI Classification based on Audio Input

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        body = deepcopy_minimal({"file": file})
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return await self._post(
            f"/categorize-audio/{user_id}",
            body=await async_maybe_transform(
                body, categorize_audio_create_for_user_params.CategorizeAudioCreateForUserParams
            ),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"api_key": api_key}, categorize_audio_create_for_user_params.CategorizeAudioCreateForUserParams
                ),
            ),
            cast_to=CategorizeAudioCreateForUserResponse,
        )


class CategorizeAudioResourceWithRawResponse:
    def __init__(self, categorize_audio: CategorizeAudioResource) -> None:
        self._categorize_audio = categorize_audio

        self.create = to_raw_response_wrapper(
            categorize_audio.create,
        )
        self.create_for_user = to_raw_response_wrapper(
            categorize_audio.create_for_user,
        )


class AsyncCategorizeAudioResourceWithRawResponse:
    def __init__(self, categorize_audio: AsyncCategorizeAudioResource) -> None:
        self._categorize_audio = categorize_audio

        self.create = async_to_raw_response_wrapper(
            categorize_audio.create,
        )
        self.create_for_user = async_to_raw_response_wrapper(
            categorize_audio.create_for_user,
        )


class CategorizeAudioResourceWithStreamingResponse:
    def __init__(self, categorize_audio: CategorizeAudioResource) -> None:
        self._categorize_audio = categorize_audio

        self.create = to_streamed_response_wrapper(
            categorize_audio.create,
        )
        self.create_for_user = to_streamed_response_wrapper(
            categorize_audio.create_for_user,
        )


class AsyncCategorizeAudioResourceWithStreamingResponse:
    def __init__(self, categorize_audio: AsyncCategorizeAudioResource) -> None:
        self._categorize_audio = categorize_audio

        self.create = async_to_streamed_response_wrapper(
            categorize_audio.create,
        )
        self.create_for_user = async_to_streamed_response_wrapper(
            categorize_audio.create_for_user,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "GetUserAnalysisRetrieveResponse",
    "User",
    "UserTextCall",
    "UserTextCallResult",
    "UserTextCallResultEmotions",
    "UserTextCallResultMotives",
    "UserTextCallResultPreferences",
]


class UserTextCallResultEmotions(BaseModel):
    approach: Optional[float] = None
    """Approach in percent between 0 and 100."""

    avoidance: Optional[float] = None
    """Avoidance in percent between 0 and 100."""


class UserTextCallResultMotives(BaseModel):
    achievement: Optional[float] = None
    """Achievement motive in percent between 0 and 100."""

    contact: Optional[float] = None
    """Contact motive in percent between 0 and 100."""

    power: Optional[float] = None
    """Power motive in percent between 0 and 100."""


class UserTextCallResultPreferences(BaseModel):
    analytical: Optional[float] = None
    """Analytical Orientation in percent between 0 and 100."""

    detail: Optional[float] = None
    """Orientation towards Details in percent between 0 and 100."""

    external: Optional[float] = None
    """External Orientation in percent between 0 and 100."""

    goal: Optional[float] = None
    """Goal-Orientation in percent between 0 and 100."""

    holistic: Optional[float] = None
    """Holistic Orientation in percent between 0 and 100."""

    internal: Optional[float] = None
    """Internal Orientation in percent between 0 and 100."""

    path: Optional[float] = None
    """Path-Orientation in percent between 0 and 100."""

    realization: Optional[float] = None
    """Orientation towards Realization in percent between 0 and 100."""


class UserTextCallResult(BaseModel):
    emotions: Optional[UserTextCallResultEmotions] = None

    motives: Optional[UserTextCallResultMotives] = None

    preferences: Optional[UserTextCallResultPreferences] = None


class UserTextCall(BaseModel):
    result: Optional[UserTextCallResult] = None

    text: Optional[str] = None
    """Text transcribed from audio input"""


class User(BaseModel):
    created_at: Optional[str] = FieldInfo(alias="createdAt", default=None)
    """Date of creation"""

    text_calls: Optional[List[UserTextCall]] = FieldInfo(alias="textCalls", default=None)

    updated_at: Optional[str] = FieldInfo(alias="updatedAt", default=None)
    """Date of last update"""

    user_id: Optional[str] = FieldInfo(alias="userId", default=None)
    """User id"""


class GetUserAnalysisRetrieveResponse(BaseModel):
    user: Optional[User] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, Union, Mapping
from typing_extensions import Self, override

import httpx

from . import _exceptions
from ._qs import Querystring
from ._types import (
    NOT_GIVEN,
    Omit,
    Headers,
    Timeout,
    NotGiven,
    Transport,
    ProxiesTypes,
    RequestOptions,
)
from ._utils import is_given, get_async_library
from ._version import __version__
from .resources import (
    chat,
    get_call,
    get_user,
    summarize,
    chat_result,
    chat_stream,
    create_user,
    analyze_team,
    get_user_chats,
    categorize_text,
    sales_assistant,
    categorize_audio,
    get_user_analysis,
    mental_health_chatbot,
)
from ._streaming import Stream as Stream, AsyncStream as AsyncStream
from ._exceptions import APIStatusError
from ._base_client import (
    DEFAULT_MAX_RETRIES,
    SyncAPIClient,
    AsyncAPIClient,
)

__all__ = [
    "Timeout",
    "Transport",
    "ProxiesTypes",
    "RequestOptions",
    "Millionways",
    "AsyncMillionways",
    "Client",
    "AsyncClient",
]


class Millionways(SyncAPIClient):
    get_call: get_call.GetCallResource
    get_user_analysis: get_user_analysis.GetUserAnalysisResource
    get_user_chats: get_user_chats.GetUserChatsResource
    create_user: create_user.CreateUserResource
    categorize_text: categorize_text.CategorizeTextResource
    analyze_team: analyze_team.AnalyzeTeamResource
    categorize_audio: categorize_audio.CategorizeAudioResource
    chat: chat.ChatResource
    chat_result: chat_result.ChatResultResource
    mental_health_chatbot: mental_health_chatbot.MentalHealthChatbotResource
    chat_stream: chat_stream.ChatStreamResource
    sales_assistant: sales_assistant.SalesAssistantResource
    summarize: summarize.SummarizeResource
    get_user: get_user.GetUserResource
    with_raw_response: MillionwaysWithRawResponse
    with_streaming_response: MillionwaysWithStreamedResponse

    # client options
    api_key: str | None

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#client) for more details.
        http_client: httpx.Client | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new synchronous Millionways client instance.

        This automatically infers the `api_key` argument from the `MILLIONWAYS_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("MILLIONWAYS_API_KEY")
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("MILLIONWAYS_BASE_URL")
        if base_url is None:
            base_url = f"https://api.millionways.org"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.get_call = get_call.GetCallResource(self)
        self.get_user_analysis = get_user_analysis.GetUserAnalysisResource(self)
        self.get_user_chats = get_user_chats.GetUserChatsResource(self)
        self.create_user = create_user.CreateUserResource(self)
        self.categorize_text = categorize_text.CategorizeTextResource(self)
        self.analyze_team = analyze_team.AnalyzeTeamResource(self)
        self.categorize_audio = categorize_audio.CategorizeAudioResource(self)
        self.chat = chat.ChatResource(self)
        self.chat_result = chat_result.ChatResultResource(self)
        self.mental_health_chatbot = mental_health_chatbot.MentalHealthChatbotResource(self)
        self.chat_stream = chat_stream.ChatStreamResource(self)
        self.sales_assistant = sales_assistant.SalesAssistantResource(self)
        self.summarize = summarize.SummarizeResource(self)
        self.get_user = get_user.GetUserResource(self)
        self.with_raw_response = MillionwaysWithRawResponse(self)
        self.with_streaming_response = MillionwaysWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        if api_key is None:
            return {}
        return {"Authorization": f"Bearer {api_key}"}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": "false",
            **self._custom_headers,
        }

    @override
    def _validate_headers(self, headers: Headers, custom_headers: Headers) -> None:
        if self.api_key and headers.get("Authorization"):
            return
        if isinstance(custom_headers.get("Authorization"), Omit):
            return

        raise TypeError(
            '"Could not resolve authentication method. Expected the api_key to be set. Or for the `Authorization` headers to be explicitly omitted"'
        )

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = NOT_GIVEN,
        http_client: httpx.Client | None = None,
        max_retries: int | NotGiven = NOT_GIVEN,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AsyncMillionways(AsyncAPIClient):
    get_call: get_call.AsyncGetCallResource
    get_user_analysis: get_user_analysis.AsyncGetUserAnalysisResource
    get_user_chats: get_user_chats.AsyncGetUserChatsResource
    create_user: create_user.AsyncCreateUserResource
    categorize_text: categorize_text.AsyncCategorizeTextResource
    analyze_team: analyze_team.AsyncAnalyzeTeamResource
    categorize_audio: categorize_audio.AsyncCategorizeAudioResource
    chat: chat.AsyncChatResource
    chat_result: chat_result.AsyncChatResultResource
    mental_health_chatbot: mental_health_chatbot.AsyncMentalHealthChatbotResource
    chat_stream: chat_stream.AsyncChatStreamResource
    sales_assistant: sales_assistant.AsyncSalesAssistantResource
    summarize: summarize.AsyncSummarizeResource
    get_user: get_user.AsyncGetUserResource
    with_raw_response: AsyncMillionwaysWithRawResponse
    with_streaming_response: AsyncMillionwaysWithStreamedResponse

    # client options
    api_key: str | None

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultAsyncHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#asyncclient) for more details.
        http_client: httpx.AsyncClient | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new async AsyncMillionways client instance.

        This automatically infers the `api_key` argument from the `MILLIONWAYS_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("MILLIONWAYS_API_KEY")
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("MILLIONWAYS_BASE_URL")
        if base_url is None:
            base_url = f"https://api.millionways.org"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.get_call = get_call.AsyncGetCallResource(self)
        self.get_user_analysis = get_user_analysis.AsyncGetUserAnalysisResource(self)
        self.get_user_chats = get_user_chats.AsyncGetUserChatsResource(self)
        self.create_user = create_user.AsyncCreateUserResource(self)
        self.categorize_text = categorize_text.AsyncCategorizeTextResource(self)
        self.analyze_team = analyze_team.AsyncAnalyzeTeamResource(self)
        self.categorize_audio = categorize_audio.AsyncCategorizeAudioResource(self)
        self.chat = chat.AsyncChatResource(self)
        self.chat_result = chat_result.AsyncChatResultResource(self)
        self.mental_health_chatbot = mental_health_chatbot.AsyncMentalHealthChatbotResource(self)
        self.chat_stream = chat_stream.AsyncChatStreamResource(self)
        self.sales_assistant = sales_assistant.AsyncSalesAssistantResource(self)
        self.summarize = summarize.AsyncSummarizeResource(self)
        self.get_user = get_user.AsyncGetUserResource(self)
        self.with_raw_response = AsyncMillionwaysWithRawResponse(self)
        self.with_streaming_response = AsyncMillionwaysWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        if api_key is None:
            return {}
        return {"Authorization": f"Bearer {api_key}"}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": f"async:{get_async_library()}",
            **self._custom_headers,
        }

    @override
    def _validate_headers(self, headers: Headers, custom_headers: Headers) -> None:
        if self.api_key and headers.get("Authorization"):
            return
        if isinstance(custom_headers.get("Authorization"), Omit):
            return

        raise TypeError(
            '"Could not resolve authentication method. Expected the api_key to be set. Or for the `Authorization` headers to be explicitly omitted"'
        )

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = NOT_GIVEN,
        http_client: httpx.AsyncClient | None = None,
        max_retries: int | NotGiven = NOT_GIVEN,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class MillionwaysWithRawResponse:
    def __init__(self, client: Millionways) -> None:
        self.get_call = get_call.GetCallResourceWithRawResponse(client.get_call)
        self.get_user_analysis = get_user_analysis.GetUserAnalysisResourceWithRawResponse(client.get_user_analysis)
        self.get_user_chats = get_user_chats.GetUserChatsResourceWithRawResponse(client.get_user_chats)
        self.create_user = create_user.CreateUserResourceWithRawResponse(client.create_user)
        self.categorize_text = categorize_text.CategorizeTextResourceWithRawResponse(client.categorize_text)
        self.analyze_team = analyze_team.AnalyzeTeamResourceWithRawResponse(client.analyze_team)
        self.categorize_audio = categorize_audio.CategorizeAudioResourceWithRawResponse(client.categorize_audio)
        self.chat = chat.ChatResourceWithRawResponse(client.chat)
        self.chat_result = chat_result.ChatResultResourceWithRawResponse(client.chat_result)
        self.mental_health_chatbot = mental_health_chatbot.MentalHealthChatbotResourceWithRawResponse(
            client.mental_health_chatbot
        )
        self.chat_stream = chat_stream.ChatStreamResourceWithRawResponse(client.chat_stream)
        self.sales_assistant = sales_assistant.SalesAssistantResourceWithRawResponse(client.sales_assistant)
        self.summarize = summarize.SummarizeResourceWithRawResponse(client.summarize)
        self.get_user = get_user.GetUserResourceWithRawResponse(client.get_user)


class AsyncMillionwaysWithRawResponse:
    def __init__(self, client: AsyncMillionways) -> None:
        self.get_call = get_call.AsyncGetCallResourceWithRawResponse(client.get_call)
        self.get_user_analysis = get_user_analysis.AsyncGetUserAnalysisResourceWithRawResponse(client.get_user_analysis)
        self.get_user_chats = get_user_chats.AsyncGetUserChatsResourceWithRawResponse(client.get_user_chats)
        self.create_user = create_user.AsyncCreateUserResourceWithRawResponse(client.create_user)
        self.categorize_text = categorize_text.AsyncCategorizeTextResourceWithRawResponse(client.categorize_text)
        self.analyze_team = analyze_team.AsyncAnalyzeTeamResourceWithRawResponse(client.analyze_team)
        self.categorize_audio = categorize_audio.AsyncCategorizeAudioResourceWithRawResponse(client.categorize_audio)
        self.chat = chat.AsyncChatResourceWithRawResponse(client.chat)
        self.chat_result = chat_result.AsyncChatResultResourceWithRawResponse(client.chat_result)
        self.mental_health_chatbot = mental_health_chatbot.AsyncMentalHealthChatbotResourceWithRawResponse(
            client.mental_health_chatbot
        )
        self.chat_stream = chat_stream.AsyncChatStreamResourceWithRawResponse(client.chat_stream)
        self.sales_assistant = sales_assistant.AsyncSalesAssistantResourceWithRawResponse(client.sales_assistant)
        self.summarize = summarize.AsyncSummarizeResourceWithRawResponse(client.summarize)
        self.get_user = get_user.AsyncGetUserResourceWithRawResponse(client.get_user)


class MillionwaysWithStreamedResponse:
    def __init__(self, client: Millionways) -> None:
        self.get_call = get_call.GetCallResourceWithStreamingResponse(client.get_call)
        self.get_user_analysis = get_user_analysis.GetUserAnalysisResourceWithStreamingResponse(
            client.get_user_analysis
        )
        self.get_user_chats = get_user_chats.GetUserChatsResourceWithStreamingResponse(client.get_user_chats)
        self.create_user = create_user.CreateUserResourceWithStreamingResponse(client.create_user)
        self.categorize_text = categorize_text.CategorizeTextResourceWithStreamingResponse(client.categorize_text)
        self.analyze_team = analyze_team.AnalyzeTeamResourceWithStreamingResponse(client.analyze_team)
        self.categorize_audio = categorize_audio.CategorizeAudioResourceWithStreamingResponse(client.categorize_audio)
        self.chat = chat.ChatResourceWithStreamingResponse(client.chat)
        self.chat_result = chat_result.ChatResultResourceWithStreamingResponse(client.chat_result)
        self.mental_health_chatbot = mental_health_chatbot.MentalHealthChatbotResourceWithStreamingResponse(
            client.mental_health_chatbot
        )
        self.chat_stream = chat_stream.ChatStreamResourceWithStreamingResponse(client.chat_stream)
        self.sales_assistant = sales_assistant.SalesAssistantResourceWithStreamingResponse(client.sales_assistant)
        self.summarize = summarize.SummarizeResourceWithStreamingResponse(client.summarize)
        self.get_user = get_user.GetUserResourceWithStreamingResponse(client.get_user)


class AsyncMillionwaysWithStreamedResponse:
    def __init__(self, client: AsyncMillionways) -> None:
        self.get_call = get_call.AsyncGetCallResourceWithStreamingResponse(client.get_call)
        self.get_user_analysis = get_user_analysis.AsyncGetUserAnalysisResourceWithStreamingResponse(
            client.get_user_analysis
        )
        self.get_user_chats = get_user_chats.AsyncGetUserChatsResourceWithStreamingResponse(client.get_user_chats)
        self.create_user = create_user.AsyncCreateUserResourceWithStreamingResponse(client.create_user)
        self.categorize_text = categorize_text.AsyncCategorizeTextResourceWithStreamingResponse(client.categorize_text)
        self.analyze_team = analyze_team.AsyncAnalyzeTeamResourceWithStreamingResponse(client.analyze_team)
        self.categorize_audio = categorize_audio.AsyncCategorizeAudioResourceWithStreamingResponse(
            client.categorize_audio
        )
        self.chat = chat.AsyncChatResourceWithStreamingResponse(client.chat)
        self.chat_result = chat_result.AsyncChatResultResourceWithStreamingResponse(client.chat_result)
        self.mental_health_chatbot = mental_health_chatbot.AsyncMentalHealthChatbotResourceWithStreamingResponse(
            client.mental_health_chatbot
        )
        self.chat_stream = chat_stream.AsyncChatStreamResourceWithStreamingResponse(client.chat_stream)
        self.sales_assistant = sales_assistant.AsyncSalesAssistantResourceWithStreamingResponse(client.sales_assistant)
        self.summarize = summarize.AsyncSummarizeResourceWithStreamingResponse(client.summarize)
        self.get_user = get_user.AsyncGetUserResourceWithStreamingResponse(client.get_user)


Client = Millionways

AsyncClient = AsyncMillionways



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "AnalyzeTeamCreateResponse",
    "Levels",
    "Result",
    "ResultEmotions",
    "ResultMotives",
    "ResultPreferences",
    "TeamTexts",
    "TeamTextsMotives",
    "TeamTextsPreferences",
]


class Levels(BaseModel):
    level1: Optional[float] = None
    """Intuition Intrinsic"""

    level2: Optional[float] = None
    """Intuition Extrinsic"""

    level3: Optional[float] = None
    """External managing of frustration"""

    level4: Optional[float] = None
    """Analytical / Intentional feelings"""

    level5: Optional[float] = None
    """Negative emotions"""


class ResultEmotions(BaseModel):
    approach: Optional[float] = None
    """Approach in percent between 0 and 100."""

    avoidance: Optional[float] = None
    """Avoidance in percent between 0 and 100."""


class ResultMotives(BaseModel):
    achievement: Optional[float] = None
    """Achievement motive in percent between 0 and 100."""

    contact: Optional[float] = None
    """Contact motive in percent between 0 and 100."""

    power: Optional[float] = None
    """Power motive in percent between 0 and 100."""


class ResultPreferences(BaseModel):
    analytical: Optional[float] = None
    """Analytical Orientation in percent between 0 and 100."""

    detail: Optional[float] = None
    """Orientation towards Details in percent between 0 and 100."""

    external: Optional[float] = None
    """External Orientation in percent between 0 and 100."""

    goal: Optional[float] = None
    """Goal-Orientation in percent between 0 and 100."""

    holistic: Optional[float] = None
    """Holistic Orientation in percent between 0 and 100."""

    internal: Optional[float] = None
    """Internal Orientation in percent between 0 and 100."""

    path: Optional[float] = None
    """Path-Orientation in percent between 0 and 100."""

    realization: Optional[float] = None
    """Orientation towards Realization in percent between 0 and 100."""


class Result(BaseModel):
    emotions: Optional[ResultEmotions] = None

    motives: Optional[ResultMotives] = None

    preferences: Optional[ResultPreferences] = None


class TeamTextsMotives(BaseModel):
    achievement: Optional[str] = None
    """Achievement motive response"""

    contact: Optional[str] = None
    """Contact motive response"""

    power: Optional[str] = None
    """Power motive response"""


class TeamTextsPreferences(BaseModel):
    action: Optional[str] = None
    """Action response"""

    attitude: Optional[str] = None
    """Attitude response"""

    energy: Optional[str] = None
    """Energy response"""

    focus: Optional[str] = None
    """Focus response"""


class TeamTexts(BaseModel):
    emotions: Optional[str] = None
    """Emotions response"""

    motives: Optional[TeamTextsMotives] = None

    preferences: Optional[TeamTextsPreferences] = None


class AnalyzeTeamCreateResponse(BaseModel):
    created_at: Optional[str] = FieldInfo(alias="createdAt", default=None)
    """Date of creation"""

    levels: Optional[Levels] = None

    result: Optional[Result] = None

    team_texts: Optional[TeamTexts] = FieldInfo(alias="teamTexts", default=None)

    text: Optional[str] = None
    """Text input that was classified"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import get_user_analysis_retrieve_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.get_user_analysis_retrieve_response import GetUserAnalysisRetrieveResponse

__all__ = ["GetUserAnalysisResource", "AsyncGetUserAnalysisResource"]


class GetUserAnalysisResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> GetUserAnalysisResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#accessing-raw-response-data-eg-headers
        """
        return GetUserAnalysisResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> GetUserAnalysisResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#with_streaming_response
        """
        return GetUserAnalysisResourceWithStreamingResponse(self)

    def retrieve(
        self,
        user_id: str,
        *,
        api_key: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GetUserAnalysisRetrieveResponse:
        """
        Get user analysis by id

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return self._get(
            f"/get-user-analysis/{user_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"api_key": api_key}, get_user_analysis_retrieve_params.GetUserAnalysisRetrieveParams
                ),
            ),
            cast_to=GetUserAnalysisRetrieveResponse,
        )


class AsyncGetUserAnalysisResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncGetUserAnalysisResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncGetUserAnalysisResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncGetUserAnalysisResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#with_streaming_response
        """
        return AsyncGetUserAnalysisResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        user_id: str,
        *,
        api_key: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GetUserAnalysisRetrieveResponse:
        """
        Get user analysis by id

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return await self._get(
            f"/get-user-analysis/{user_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"api_key": api_key}, get_user_analysis_retrieve_params.GetUserAnalysisRetrieveParams
                ),
            ),
            cast_to=GetUserAnalysisRetrieveResponse,
        )


class GetUserAnalysisResourceWithRawResponse:
    def __init__(self, get_user_analysis: GetUserAnalysisResource) -> None:
        self._get_user_analysis = get_user_analysis

        self.retrieve = to_raw_response_wrapper(
            get_user_analysis.retrieve,
        )


class AsyncGetUserAnalysisResourceWithRawResponse:
    def __init__(self, get_user_analysis: AsyncGetUserAnalysisResource) -> None:
        self._get_user_analysis = get_user_analysis

        self.retrieve = async_to_raw_response_wrapper(
            get_user_analysis.retrieve,
        )


class GetUserAnalysisResourceWithStreamingResponse:
    def __init__(self, get_user_analysis: GetUserAnalysisResource) -> None:
        self._get_user_analysis = get_user_analysis

        self.retrieve = to_streamed_response_wrapper(
            get_user_analysis.retrieve,
        )


class AsyncGetUserAnalysisResourceWithStreamingResponse:
    def __init__(self, get_user_analysis: AsyncGetUserAnalysisResource) -> None:
        self._get_user_analysis = get_user_analysis

        self.retrieve = async_to_streamed_response_wrapper(
            get_user_analysis.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from millionways import Millionways, AsyncMillionways
from tests.utils import assert_matches_type
from millionways.types import (
    MentalHealthChatbotGenerateResponseResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMentalHealthChatbot:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_generate_response(self, client: Millionways) -> None:
        mental_health_chatbot = client.mental_health_chatbot.generate_response(
            api_key="apiKey",
        )
        assert_matches_type(MentalHealthChatbotGenerateResponseResponse, mental_health_chatbot, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_generate_response_with_all_params(self, client: Millionways) -> None:
        mental_health_chatbot = client.mental_health_chatbot.generate_response(
            api_key="apiKey",
            language="en",
            levels={
                "level1": 20,
                "level2": 20,
                "level3": 20,
                "level4": 20,
                "level5": 20,
            },
            messages=[
                {
                    "role": "user",
                    "content": "Hello",
                },
                {
                    "role": "assistant",
                    "content": "Hi, how are you?",
                },
            ],
            result={
                "emotions": {
                    "approach": 50,
                    "avoidance": 50,
                },
                "motives": {
                    "achievement": 0,
                    "contact": 100,
                    "power": 0,
                },
                "preferences": {
                    "analytical": 50,
                    "detail": 50,
                    "external": 100,
                    "goal": 100,
                    "holistic": 50,
                    "internal": 0,
                    "path": 0,
                    "realization": 50,
                },
            },
        )
        assert_matches_type(MentalHealthChatbotGenerateResponseResponse, mental_health_chatbot, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_generate_response(self, client: Millionways) -> None:
        response = client.mental_health_chatbot.with_raw_response.generate_response(
            api_key="apiKey",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mental_health_chatbot = response.parse()
        assert_matches_type(MentalHealthChatbotGenerateResponseResponse, mental_health_chatbot, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_generate_response(self, client: Millionways) -> None:
        with client.mental_health_chatbot.with_streaming_response.generate_response(
            api_key="apiKey",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mental_health_chatbot = response.parse()
            assert_matches_type(MentalHealthChatbotGenerateResponseResponse, mental_health_chatbot, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncMentalHealthChatbot:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_generate_response(self, async_client: AsyncMillionways) -> None:
        mental_health_chatbot = await async_client.mental_health_chatbot.generate_response(
            api_key="apiKey",
        )
        assert_matches_type(MentalHealthChatbotGenerateResponseResponse, mental_health_chatbot, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_generate_response_with_all_params(self, async_client: AsyncMillionways) -> None:
        mental_health_chatbot = await async_client.mental_health_chatbot.generate_response(
            api_key="apiKey",
            language="en",
            levels={
                "level1": 20,
                "level2": 20,
                "level3": 20,
                "level4": 20,
                "level5": 20,
            },
            messages=[
                {
                    "role": "user",
                    "content": "Hello",
                },
                {
                    "role": "assistant",
                    "content": "Hi, how are you?",
                },
            ],
            result={
                "emotions": {
                    "approach": 50,
                    "avoidance": 50,
                },
                "motives": {
                    "achievement": 0,
                    "contact": 100,
                    "power": 0,
                },
                "preferences": {
                    "analytical": 50,
                    "detail": 50,
                    "external": 100,
                    "goal": 100,
                    "holistic": 50,
                    "internal": 0,
                    "path": 0,
                    "realization": 50,
                },
            },
        )
        assert_matches_type(MentalHealthChatbotGenerateResponseResponse, mental_health_chatbot, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_generate_response(self, async_client: AsyncMillionways) -> None:
        response = await async_client.mental_health_chatbot.with_raw_response.generate_response(
            api_key="apiKey",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mental_health_chatbot = await response.parse()
        assert_matches_type(MentalHealthChatbotGenerateResponseResponse, mental_health_chatbot, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_generate_response(self, async_client: AsyncMillionways) -> None:
        async with async_client.mental_health_chatbot.with_streaming_response.generate_response(
            api_key="apiKey",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mental_health_chatbot = await response.parse()
            assert_matches_type(MentalHealthChatbotGenerateResponseResponse, mental_health_chatbot, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from millionways import Millionways, AsyncMillionways
from tests.utils import assert_matches_type
from millionways.types import (
    ChatGenerateResponseResponse,
    ChatGenerateResponseForUserResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestChat:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_generate_response(self, client: Millionways) -> None:
        chat = client.chat.generate_response(
            api_key="apiKey",
        )
        assert_matches_type(ChatGenerateResponseResponse, chat, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_generate_response_with_all_params(self, client: Millionways) -> None:
        chat = client.chat.generate_response(
            api_key="apiKey",
            language="en",
            messages=[
                {
                    "role": "user",
                    "content": "Hello",
                },
                {
                    "role": "assistant",
                    "content": "Hi, how are you?",
                },
            ],
        )
        assert_matches_type(ChatGenerateResponseResponse, chat, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_generate_response(self, client: Millionways) -> None:
        response = client.chat.with_raw_response.generate_response(
            api_key="apiKey",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = response.parse()
        assert_matches_type(ChatGenerateResponseResponse, chat, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_generate_response(self, client: Millionways) -> None:
        with client.chat.with_streaming_response.generate_response(
            api_key="apiKey",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = response.parse()
            assert_matches_type(ChatGenerateResponseResponse, chat, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_generate_response_for_user(self, client: Millionways) -> None:
        chat = client.chat.generate_response_for_user(
            user_id="userId",
            api_key="apiKey",
        )
        assert_matches_type(ChatGenerateResponseForUserResponse, chat, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_generate_response_for_user_with_all_params(self, client: Millionways) -> None:
        chat = client.chat.generate_response_for_user(
            user_id="userId",
            api_key="apiKey",
            language="en",
            messages=[
                {
                    "role": "user",
                    "content": "Hello",
                },
                {
                    "role": "assistant",
                    "content": "Hi, how are you?",
                },
            ],
        )
        assert_matches_type(ChatGenerateResponseForUserResponse, chat, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_generate_response_for_user(self, client: Millionways) -> None:
        response = client.chat.with_raw_response.generate_response_for_user(
            user_id="userId",
            api_key="apiKey",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = response.parse()
        assert_matches_type(ChatGenerateResponseForUserResponse, chat, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_generate_response_for_user(self, client: Millionways) -> None:
        with client.chat.with_streaming_response.generate_response_for_user(
            user_id="userId",
            api_key="apiKey",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = response.parse()
            assert_matches_type(ChatGenerateResponseForUserResponse, chat, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_generate_response_for_user(self, client: Millionways) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `user_id` but received ''"):
            client.chat.with_raw_response.generate_response_for_user(
                user_id="",
                api_key="apiKey",
            )


class TestAsyncChat:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_generate_response(self, async_client: AsyncMillionways) -> None:
        chat = await async_client.chat.generate_response(
            api_key="apiKey",
        )
        assert_matches_type(ChatGenerateResponseResponse, chat, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_generate_response_with_all_params(self, async_client: AsyncMillionways) -> None:
        chat = await async_client.chat.generate_response(
            api_key="apiKey",
            language="en",
            messages=[
                {
                    "role": "user",
                    "content": "Hello",
                },
                {
                    "role": "assistant",
                    "content": "Hi, how are you?",
                },
            ],
        )
        assert_matches_type(ChatGenerateResponseResponse, chat, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_generate_response(self, async_client: AsyncMillionways) -> None:
        response = await async_client.chat.with_raw_response.generate_response(
            api_key="apiKey",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = await response.parse()
        assert_matches_type(ChatGenerateResponseResponse, chat, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_generate_response(self, async_client: AsyncMillionways) -> None:
        async with async_client.chat.with_streaming_response.generate_response(
            api_key="apiKey",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = await response.parse()
            assert_matches_type(ChatGenerateResponseResponse, chat, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_generate_response_for_user(self, async_client: AsyncMillionways) -> None:
        chat = await async_client.chat.generate_response_for_user(
            user_id="userId",
            api_key="apiKey",
        )
        assert_matches_type(ChatGenerateResponseForUserResponse, chat, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_generate_response_for_user_with_all_params(self, async_client: AsyncMillionways) -> None:
        chat = await async_client.chat.generate_response_for_user(
            user_id="userId",
            api_key="apiKey",
            language="en",
            messages=[
                {
                    "role": "user",
                    "content": "Hello",
                },
                {
                    "role": "assistant",
                    "content": "Hi, how are you?",
                },
            ],
        )
        assert_matches_type(ChatGenerateResponseForUserResponse, chat, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_generate_response_for_user(self, async_client: AsyncMillionways) -> None:
        response = await async_client.chat.with_raw_response.generate_response_for_user(
            user_id="userId",
            api_key="apiKey",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = await response.parse()
        assert_matches_type(ChatGenerateResponseForUserResponse, chat, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_generate_response_for_user(self, async_client: AsyncMillionways) -> None:
        async with async_client.chat.with_streaming_response.generate_response_for_user(
            user_id="userId",
            api_key="apiKey",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = await response.parse()
            assert_matches_type(ChatGenerateResponseForUserResponse, chat, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_generate_response_for_user(self, async_client: AsyncMillionways) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `user_id` but received ''"):
            await async_client.chat.with_raw_response.generate_response_for_user(
                user_id="",
                api_key="apiKey",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from millionways import Millionways, AsyncMillionways
from tests.utils import assert_matches_type
from millionways.types import AnalyzeTeamCreateResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAnalyzeTeam:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: Millionways) -> None:
        analyze_team = client.analyze_team.create(
            api_key="apiKey",
        )
        assert_matches_type(AnalyzeTeamCreateResponse, analyze_team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: Millionways) -> None:
        analyze_team = client.analyze_team.create(
            api_key="apiKey",
            language="en",
            text="I am feeling good today and I want to go outside and meet some people.",
        )
        assert_matches_type(AnalyzeTeamCreateResponse, analyze_team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: Millionways) -> None:
        response = client.analyze_team.with_raw_response.create(
            api_key="apiKey",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        analyze_team = response.parse()
        assert_matches_type(AnalyzeTeamCreateResponse, analyze_team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: Millionways) -> None:
        with client.analyze_team.with_streaming_response.create(
            api_key="apiKey",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            analyze_team = response.parse()
            assert_matches_type(AnalyzeTeamCreateResponse, analyze_team, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncAnalyzeTeam:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncMillionways) -> None:
        analyze_team = await async_client.analyze_team.create(
            api_key="apiKey",
        )
        assert_matches_type(AnalyzeTeamCreateResponse, analyze_team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncMillionways) -> None:
        analyze_team = await async_client.analyze_team.create(
            api_key="apiKey",
            language="en",
            text="I am feeling good today and I want to go outside and meet some people.",
        )
        assert_matches_type(AnalyzeTeamCreateResponse, analyze_team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncMillionways) -> None:
        response = await async_client.analyze_team.with_raw_response.create(
            api_key="apiKey",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        analyze_team = await response.parse()
        assert_matches_type(AnalyzeTeamCreateResponse, analyze_team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncMillionways) -> None:
        async with async_client.analyze_team.with_streaming_response.create(
            api_key="apiKey",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            analyze_team = await response.parse()
            assert_matches_type(AnalyzeTeamCreateResponse, analyze_team, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["GetUserRetrieveParams"]


class GetUserRetrieveParams(TypedDict, total=False):
    api_key: Required[Annotated[str, PropertyInfo(alias="apiKey")]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["GetUserRetrieveResponse", "User"]


class User(BaseModel):
    api_id: Optional[str] = FieldInfo(alias="_id", default=None)
    """User id"""

    api_calls: Optional[List[str]] = FieldInfo(alias="apiCalls", default=None)
    """Array containing the IDs of all API Calls associated with this User"""

    created_at: Optional[str] = FieldInfo(alias="createdAt", default=None)
    """Date of creation"""

    customer_id: Optional[str] = FieldInfo(alias="customerId", default=None)
    """Customer ID that the User belongs to"""

    updated_at: Optional[str] = FieldInfo(alias="updatedAt", default=None)
    """Date of last update"""


class GetUserRetrieveResponse(BaseModel):
    user: Optional[User] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ChatGenerateResponseParams"]


class ChatGenerateResponseParams(TypedDict, total=False):
    api_key: Required[Annotated[str, PropertyInfo(alias="apiKey")]]

    language: str
    """language parameter, defaults to en"""

    messages: Iterable[object]
    """
    history of messages between user with the role 'user' and chatbot with the role
    'assistant'
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .chat import (
    ChatResource,
    AsyncChatResource,
    ChatResourceWithRawResponse,
    AsyncChatResourceWithRawResponse,
    ChatResourceWithStreamingResponse,
    AsyncChatResourceWithStreamingResponse,
)
from .get_call import (
    GetCallResource,
    AsyncGetCallResource,
    GetCallResourceWithRawResponse,
    AsyncGetCallResourceWithRawResponse,
    GetCallResourceWithStreamingResponse,
    AsyncGetCallResourceWithStreamingResponse,
)
from .get_user import (
    GetUserResource,
    AsyncGetUserResource,
    GetUserResourceWithRawResponse,
    AsyncGetUserResourceWithRawResponse,
    GetUserResourceWithStreamingResponse,
    AsyncGetUserResourceWithStreamingResponse,
)
from .summarize import (
    SummarizeResource,
    AsyncSummarizeResource,
    SummarizeResourceWithRawResponse,
    AsyncSummarizeResourceWithRawResponse,
    SummarizeResourceWithStreamingResponse,
    AsyncSummarizeResourceWithStreamingResponse,
)
from .chat_result import (
    ChatResultResource,
    AsyncChatResultResource,
    ChatResultResourceWithRawResponse,
    AsyncChatResultResourceWithRawResponse,
    ChatResultResourceWithStreamingResponse,
    AsyncChatResultResourceWithStreamingResponse,
)
from .chat_stream import (
    ChatStreamResource,
    AsyncChatStreamResource,
    ChatStreamResourceWithRawResponse,
    AsyncChatStreamResourceWithRawResponse,
    ChatStreamResourceWithStreamingResponse,
    AsyncChatStreamResourceWithStreamingResponse,
)
from .create_user import (
    CreateUserResource,
    AsyncCreateUserResource,
    CreateUserResourceWithRawResponse,
    AsyncCreateUserResourceWithRawResponse,
    CreateUserResourceWithStreamingResponse,
    AsyncCreateUserResourceWithStreamingResponse,
)
from .analyze_team import (
    AnalyzeTeamResource,
    AsyncAnalyzeTeamResource,
    AnalyzeTeamResourceWithRawResponse,
    AsyncAnalyzeTeamResourceWithRawResponse,
    AnalyzeTeamResourceWithStreamingResponse,
    AsyncAnalyzeTeamResourceWithStreamingResponse,
)
from .get_user_chats import (
    GetUserChatsResource,
    AsyncGetUserChatsResource,
    GetUserChatsResourceWithRawResponse,
    AsyncGetUserChatsResourceWithRawResponse,
    GetUserChatsResourceWithStreamingResponse,
    AsyncGetUserChatsResourceWithStreamingResponse,
)
from .categorize_text import (
    CategorizeTextResource,
    AsyncCategorizeTextResource,
    CategorizeTextResourceWithRawResponse,
    AsyncCategorizeTextResourceWithRawResponse,
    CategorizeTextResourceWithStreamingResponse,
    AsyncCategorizeTextResourceWithStreamingResponse,
)
from .sales_assistant import (
    SalesAssistantResource,
    AsyncSalesAssistantResource,
    SalesAssistantResourceWithRawResponse,
    AsyncSalesAssistantResourceWithRawResponse,
    SalesAssistantResourceWithStreamingResponse,
    AsyncSalesAssistantResourceWithStreamingResponse,
)
from .categorize_audio import (
    CategorizeAudioResource,
    AsyncCategorizeAudioResource,
    CategorizeAudioResourceWithRawResponse,
    AsyncCategorizeAudioResourceWithRawResponse,
    CategorizeAudioResourceWithStreamingResponse,
    AsyncCategorizeAudioResourceWithStreamingResponse,
)
from .get_user_analysis import (
    GetUserAnalysisResource,
    AsyncGetUserAnalysisResource,
    GetUserAnalysisResourceWithRawResponse,
    AsyncGetUserAnalysisResourceWithRawResponse,
    GetUserAnalysisResourceWithStreamingResponse,
    AsyncGetUserAnalysisResourceWithStreamingResponse,
)
from .mental_health_chatbot import (
    MentalHealthChatbotResource,
    AsyncMentalHealthChatbotResource,
    MentalHealthChatbotResourceWithRawResponse,
    AsyncMentalHealthChatbotResourceWithRawResponse,
    MentalHealthChatbotResourceWithStreamingResponse,
    AsyncMentalHealthChatbotResourceWithStreamingResponse,
)

__all__ = [
    "GetCallResource",
    "AsyncGetCallResource",
    "GetCallResourceWithRawResponse",
    "AsyncGetCallResourceWithRawResponse",
    "GetCallResourceWithStreamingResponse",
    "AsyncGetCallResourceWithStreamingResponse",
    "GetUserAnalysisResource",
    "AsyncGetUserAnalysisResource",
    "GetUserAnalysisResourceWithRawResponse",
    "AsyncGetUserAnalysisResourceWithRawResponse",
    "GetUserAnalysisResourceWithStreamingResponse",
    "AsyncGetUserAnalysisResourceWithStreamingResponse",
    "GetUserChatsResource",
    "AsyncGetUserChatsResource",
    "GetUserChatsResourceWithRawResponse",
    "AsyncGetUserChatsResourceWithRawResponse",
    "GetUserChatsResourceWithStreamingResponse",
    "AsyncGetUserChatsResourceWithStreamingResponse",
    "CreateUserResource",
    "AsyncCreateUserResource",
    "CreateUserResourceWithRawResponse",
    "AsyncCreateUserResourceWithRawResponse",
    "CreateUserResourceWithStreamingResponse",
    "AsyncCreateUserResourceWithStreamingResponse",
    "CategorizeTextResource",
    "AsyncCategorizeTextResource",
    "CategorizeTextResourceWithRawResponse",
    "AsyncCategorizeTextResourceWithRawResponse",
    "CategorizeTextResourceWithStreamingResponse",
    "AsyncCategorizeTextResourceWithStreamingResponse",
    "AnalyzeTeamResource",
    "AsyncAnalyzeTeamResource",
    "AnalyzeTeamResourceWithRawResponse",
    "AsyncAnalyzeTeamResourceWithRawResponse",
    "AnalyzeTeamResourceWithStreamingResponse",
    "AsyncAnalyzeTeamResourceWithStreamingResponse",
    "CategorizeAudioResource",
    "AsyncCategorizeAudioResource",
    "CategorizeAudioResourceWithRawResponse",
    "AsyncCategorizeAudioResourceWithRawResponse",
    "CategorizeAudioResourceWithStreamingResponse",
    "AsyncCategorizeAudioResourceWithStreamingResponse",
    "ChatResource",
    "AsyncChatResource",
    "ChatResourceWithRawResponse",
    "AsyncChatResourceWithRawResponse",
    "ChatResourceWithStreamingResponse",
    "AsyncChatResourceWithStreamingResponse",
    "ChatResultResource",
    "AsyncChatResultResource",
    "ChatResultResourceWithRawResponse",
    "AsyncChatResultResourceWithRawResponse",
    "ChatResultResourceWithStreamingResponse",
    "AsyncChatResultResourceWithStreamingResponse",
    "MentalHealthChatbotResource",
    "AsyncMentalHealthChatbotResource",
    "MentalHealthChatbotResourceWithRawResponse",
    "AsyncMentalHealthChatbotResourceWithRawResponse",
    "MentalHealthChatbotResourceWithStreamingResponse",
    "AsyncMentalHealthChatbotResourceWithStreamingResponse",
    "ChatStreamResource",
    "AsyncChatStreamResource",
    "ChatStreamResourceWithRawResponse",
    "AsyncChatStreamResourceWithRawResponse",
    "ChatStreamResourceWithStreamingResponse",
    "AsyncChatStreamResourceWithStreamingResponse",
    "SalesAssistantResource",
    "AsyncSalesAssistantResource",
    "SalesAssistantResourceWithRawResponse",
    "AsyncSalesAssistantResourceWithRawResponse",
    "SalesAssistantResourceWithStreamingResponse",
    "AsyncSalesAssistantResourceWithStreamingResponse",
    "SummarizeResource",
    "AsyncSummarizeResource",
    "SummarizeResourceWithRawResponse",
    "AsyncSummarizeResourceWithRawResponse",
    "SummarizeResourceWithStreamingResponse",
    "AsyncSummarizeResourceWithStreamingResponse",
    "GetUserResource",
    "AsyncGetUserResource",
    "GetUserResourceWithRawResponse",
    "AsyncGetUserResourceWithRawResponse",
    "GetUserResourceWithStreamingResponse",
    "AsyncGetUserResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "GetCallRetrieveResponse",
    "Call",
    "CallLevels",
    "CallResponses",
    "CallResponsesMotives",
    "CallResponsesPreferences",
    "CallResult",
    "CallResultEmotions",
    "CallResultMotives",
    "CallResultPreferences",
]


class CallLevels(BaseModel):
    level1: Optional[float] = None
    """Intuition Intrinsic"""

    level2: Optional[float] = None
    """Intuition Extrinsic"""

    level3: Optional[float] = None
    """External managing of frustration"""

    level4: Optional[float] = None
    """Analytical / Intentional feelings"""

    level5: Optional[float] = None
    """Negative emotions"""


class CallResponsesMotives(BaseModel):
    achievement: Optional[str] = None
    """Achievement motive response"""

    contact: Optional[str] = None
    """Contact motive response"""

    power: Optional[str] = None
    """Power motive response"""


class CallResponsesPreferences(BaseModel):
    action: Optional[str] = None
    """Action response"""

    attitude: Optional[str] = None
    """Attitude response"""

    energy: Optional[str] = None
    """Energy response"""

    focus: Optional[str] = None
    """Focus response"""


class CallResponses(BaseModel):
    emotions: Optional[str] = None
    """Emotions response"""

    motives: Optional[CallResponsesMotives] = None

    preferences: Optional[CallResponsesPreferences] = None


class CallResultEmotions(BaseModel):
    approach: Optional[float] = None
    """Approach in percent between 0 and 100."""

    avoidance: Optional[float] = None
    """Avoidance in percent between 0 and 100."""


class CallResultMotives(BaseModel):
    achievement: Optional[float] = None
    """Achievement motive in percent between 0 and 100."""

    contact: Optional[float] = None
    """Contact motive in percent between 0 and 100."""

    power: Optional[float] = None
    """Power motive in percent between 0 and 100."""


class CallResultPreferences(BaseModel):
    analytical: Optional[float] = None
    """Analytical Orientation in percent between 0 and 100."""

    detail: Optional[float] = None
    """Orientation towards Details in percent between 0 and 100."""

    external: Optional[float] = None
    """External Orientation in percent between 0 and 100."""

    goal: Optional[float] = None
    """Goal-Orientation in percent between 0 and 100."""

    holistic: Optional[float] = None
    """Holistic Orientation in percent between 0 and 100."""

    internal: Optional[float] = None
    """Internal Orientation in percent between 0 and 100."""

    path: Optional[float] = None
    """Path-Orientation in percent between 0 and 100."""

    realization: Optional[float] = None
    """Orientation towards Realization in percent between 0 and 100."""


class CallResult(BaseModel):
    emotions: Optional[CallResultEmotions] = None

    motives: Optional[CallResultMotives] = None

    preferences: Optional[CallResultPreferences] = None


class Call(BaseModel):
    api_id: Optional[str] = FieldInfo(alias="_id", default=None)
    """Call id"""

    created_at: Optional[str] = FieldInfo(alias="createdAt", default=None)
    """Date of creation"""

    customer_id: Optional[str] = FieldInfo(alias="customerId", default=None)
    """Customer ID that the Call belongs to"""

    language: Optional[str] = None
    """Language used for the Call"""

    levels: Optional[CallLevels] = None

    responses: Optional[CallResponses] = None

    result: Optional[CallResult] = None

    text: Optional[str] = None
    """Text input"""

    type: Optional[str] = None
    """Type of the call"""

    updated_at: Optional[str] = FieldInfo(alias="updatedAt", default=None)
    """Date of last update"""

    user_id: Optional[str] = FieldInfo(alias="userId", default=None)
    """User ID that the Call belongs to"""


class GetCallRetrieveResponse(BaseModel):
    call: Optional[Call] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = [
    "MentalHealthChatbotGenerateResponseParams",
    "Levels",
    "Result",
    "ResultEmotions",
    "ResultMotives",
    "ResultPreferences",
]


class MentalHealthChatbotGenerateResponseParams(TypedDict, total=False):
    api_key: Required[Annotated[str, PropertyInfo(alias="apiKey")]]

    language: str
    """language parameter, defaults to en"""

    levels: Levels

    messages: Iterable[object]
    """
    history of messages between user with the role 'user' and chatbot with the role
    'assistant'
    """

    result: Result


class Levels(TypedDict, total=False):
    level1: float
    """Intuition Intrinsic"""

    level2: float
    """Intuition Extrinsic"""

    level3: float
    """External managing of frustration"""

    level4: float
    """Analytical / Intentional feelings"""

    level5: float
    """Negative emotions"""


class ResultEmotions(TypedDict, total=False):
    approach: float
    """Approach in percent between 0 and 100."""

    avoidance: float
    """Avoidance in percent between 0 and 100."""


class ResultMotives(TypedDict, total=False):
    achievement: float
    """Achievement motive in percent between 0 and 100."""

    contact: float
    """Contact motive in percent between 0 and 100."""

    power: float
    """Power motive in percent between 0 and 100."""


class ResultPreferences(TypedDict, total=False):
    analytical: float
    """Analytical Orientation in percent between 0 and 100."""

    detail: float
    """Orientation towards Details in percent between 0 and 100."""

    external: float
    """External Orientation in percent between 0 and 100."""

    goal: float
    """Goal-Orientation in percent between 0 and 100."""

    holistic: float
    """Holistic Orientation in percent between 0 and 100."""

    internal: float
    """Internal Orientation in percent between 0 and 100."""

    path: float
    """Path-Orientation in percent between 0 and 100."""

    realization: float
    """Orientation towards Realization in percent between 0 and 100."""


class Result(TypedDict, total=False):
    emotions: ResultEmotions

    motives: ResultMotives

    preferences: ResultPreferences



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable

import httpx

from ..types import mental_health_chatbot_generate_response_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.mental_health_chatbot_generate_response_response import MentalHealthChatbotGenerateResponseResponse

__all__ = ["MentalHealthChatbotResource", "AsyncMentalHealthChatbotResource"]


class MentalHealthChatbotResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> MentalHealthChatbotResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#accessing-raw-response-data-eg-headers
        """
        return MentalHealthChatbotResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MentalHealthChatbotResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#with_streaming_response
        """
        return MentalHealthChatbotResourceWithStreamingResponse(self)

    def generate_response(
        self,
        *,
        api_key: str,
        language: str | NotGiven = NOT_GIVEN,
        levels: mental_health_chatbot_generate_response_params.Levels | NotGiven = NOT_GIVEN,
        messages: Iterable[object] | NotGiven = NOT_GIVEN,
        result: mental_health_chatbot_generate_response_params.Result | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MentalHealthChatbotGenerateResponseResponse:
        """
        Generate emotionally intelligent mental health support chatbot response based on
        user input with given Result

        Args:
          language: language parameter, defaults to en

          messages: history of messages between user with the role 'user' and chatbot with the role
              'assistant'

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/mental-health-chatbot",
            body=maybe_transform(
                {
                    "language": language,
                    "levels": levels,
                    "messages": messages,
                    "result": result,
                },
                mental_health_chatbot_generate_response_params.MentalHealthChatbotGenerateResponseParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"api_key": api_key},
                    mental_health_chatbot_generate_response_params.MentalHealthChatbotGenerateResponseParams,
                ),
            ),
            cast_to=MentalHealthChatbotGenerateResponseResponse,
        )


class AsyncMentalHealthChatbotResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncMentalHealthChatbotResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncMentalHealthChatbotResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMentalHealthChatbotResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mwe1/millionways-python-sdk#with_streaming_response
        """
        return AsyncMentalHealthChatbotResourceWithStreamingResponse(self)

    async def generate_response(
        self,
        *,
        api_key: str,
        language: str | NotGiven = NOT_GIVEN,
        levels: mental_health_chatbot_generate_response_params.Levels | NotGiven = NOT_GIVEN,
        messages: Iterable[object] | NotGiven = NOT_GIVEN,
        result: mental_health_chatbot_generate_response_params.Result | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MentalHealthChatbotGenerateResponseResponse:
        """
        Generate emotionally intelligent mental health support chatbot response based on
        user input with given Result

        Args:
          language: language parameter, defaults to en

          messages: history of messages between user with the role 'user' and chatbot with the role
              'assistant'

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/mental-health-chatbot",
            body=await async_maybe_transform(
                {
                    "language": language,
                    "levels": levels,
                    "messages": messages,
                    "result": result,
                },
                mental_health_chatbot_generate_response_params.MentalHealthChatbotGenerateResponseParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"api_key": api_key},
                    mental_health_chatbot_generate_response_params.MentalHealthChatbotGenerateResponseParams,
                ),
            ),
            cast_to=MentalHealthChatbotGenerateResponseResponse,
        )


class MentalHealthChatbotResourceWithRawResponse:
    def __init__(self, mental_health_chatbot: MentalHealthChatbotResource) -> None:
        self._mental_health_chatbot = mental_health_chatbot

        self.generate_response = to_raw_response_wrapper(
            mental_health_chatbot.generate_response,
        )


class AsyncMentalHealthChatbotResourceWithRawResponse:
    def __init__(self, mental_health_chatbot: AsyncMentalHealthChatbotResource) -> None:
        self._mental_health_chatbot = mental_health_chatbot

        self.generate_response = async_to_raw_response_wrapper(
            mental_health_chatbot.generate_response,
        )


class MentalHealthChatbotResourceWithStreamingResponse:
    def __init__(self, mental_health_chatbot: MentalHealthChatbotResource) -> None:
        self._mental_health_chatbot = mental_health_chatbot

        self.generate_response = to_streamed_response_wrapper(
            mental_health_chatbot.generate_response,
        )


class AsyncMentalHealthChatbotResourceWithStreamingResponse:
    def __init__(self, mental_health_chatbot: AsyncMentalHealthChatbotResource) -> None:
        self._mental_health_chatbot = mental_health_chatbot

        self.generate_response = async_to_streamed_response_wrapper(
            mental_health_chatbot.generate_response,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["SalesAssistantGenerateInsightsResponse"]


class SalesAssistantGenerateInsightsResponse(BaseModel):
    assist: Optional[str] = None
    """Assisted advice for the sales rep."""

    conversion: Optional[float] = None
    """Score between 0 and 100 assessing the likelihood of the customer conversion."""

    interests: Optional[str] = None
    """Customer's interests and preferences."""

    response: Optional[str] = None
    """Recommended response for what to say next in the conversation."""

    stay_away_from: Optional[str] = None
    """Customer's dislikes or things they want to avoid."""
